<?php


/*
 * Exit if accessed directly.
 */

if ( !defined( 'ABSPATH' ) ) {
exit;
}

define( 'THEMEZINHO_PLUGIN_FILE', __FILE__ );
define( 'THEMEZINHO_PLUGIN_BASENAME', plugin_basename( __FILE__ ) );
define( 'THEMEZINHO_PLUGIN_PATH', plugin_dir_path( __FILE__ ) );
define( 'THEMEZINHO_PLUGIN_URL', plugins_url( '/', __FILE__ ) );

final class Themezinho_Elementor_Addons {

  const VERSION = '1.0.4';


  const MINIMUM_ELEMENTOR_VERSION = '2.0.0';


  const MINIMUM_PHP_VERSION = '7.0';


	private static $_instance = null;


	public static function instance() {

		if ( is_null( self::$_instance ) ) {
		  self::$_instance = new self();
		}
	  return self::$_instance;
	}


	public function __construct() {
	  add_action( 'init', [ $this, 'i18n' ] );
	  add_action( 'plugins_loaded', [ $this, 'init' ] );
	}

	public function i18n() {
	  load_plugin_textdomain( 'themezinho' );
	}


	public function init() {

	  // Check if Elementor is installed and activated
		if ( !did_action( 'elementor/loaded' ) ) {
		  add_action( 'admin_notices', [ $this, 'themezinho_admin_notice_missing_main_plugin' ] );
		  return;
		}
	  // Check for required Elementor version
		if ( !version_compare( ELEMENTOR_VERSION, self::MINIMUM_ELEMENTOR_VERSION, '>=' ) ) {
		  add_action( 'admin_notices', [ $this, 'themezinho_admin_notice_minimum_elementor_version' ] );
		  return;
		}
	  // Check for required PHP version
		if ( version_compare( PHP_VERSION, self::MINIMUM_PHP_VERSION, '<' ) ) {
		  add_action( 'admin_notices', [ $this, 'themezinho_admin_notice_minimum_php_version' ] );
		  return;
		}

	  /* Custom plugin helper functions */
	  //require_once( __DIR__ . '/class-helpers-functions.php' );


	  // Categories registered
	  add_action( 'elementor/elements/categories_registered', [ $this, 'themezinho_add_widget_category' ] );
	  // Widgets registered
	  add_action( 'elementor/widgets/register', [ $this, 'init_widgets' ] );
	  //elementor custom editor style
	  add_action( 'wp_print_styles', [ $this, 'themezinho_elementor_addons_dequeue_style' ], 100 );
	}

	public function themezinho_elementor_addons_dequeue_style() {
		if ( is_page_template( 'page-builder.php' ) ) {
		  wp_dequeue_style( 'themezinho-framework-style' );
		}
	}


	public function themezinho_admin_notice_missing_main_plugin() {

		if ( isset( $_GET[ 'activate' ] ) ) {
unset( $_GET[ 'activate' ] );
		}

	  $message = sprintf(
		/* translators: 1: Plugin name 2: Elementor */
		esc_html__( '%1$s requires %2$s to be installed and activated.', 'themezinho' ),
		'<strong>' . esc_html__( 'Themezinho Elements', 'themezinho' ) . '</strong>',
		'<strong>' . esc_html__( 'Elementor', 'themezinho' ) . '</strong>'
	  );

	echo '<div class="notice notice-warning is-dismissible"><p>' . wp_kses_post( $message ) . '</p></div>';

	}


	public function themezinho_admin_notice_minimum_elementor_version() {

		if ( isset( $_GET[ 'activate' ] ) ) {
unset( $_GET[ 'activate' ] );
		}

	  $message = sprintf(
		/* translators: 1: Plugin name 2: Elementor 3: Required Elementor version */
		esc_html__( '%1$s requires %2$s version %3$s or greater.', 'themezinho' ),
		'<strong>' . esc_html__( 'Themezinho Elements', 'themezinho' ) . '</strong>',
		'<strong>' . esc_html__( 'Elementor', 'themezinho' ) . '</strong>',
		self::MINIMUM_ELEMENTOR_VERSION
	  );

	echo '<div class="notice notice-warning is-dismissible"><p>' . wp_kses_post( $message ) . '</p></div>';


	}


	public function themezinho_admin_notice_minimum_php_version() {
		if ( isset( $_GET[ 'activate' ] ) ) {
unset( $_GET[ 'activate' ] );
		}
	  $message = sprintf(
		/* translators: 1: Plugin name 2: PHP 3: Required PHP version */
		esc_html__( '%1$s requires %2$s version %3$s or greater.', 'themezinho' ),
		'<strong>' . esc_html__( 'Themezinho Elements', 'themezinho' ) . '</strong>',
		'<strong>' . esc_html__( 'PHP', 'themezinho' ) . '</strong>',
		self::MINIMUM_PHP_VERSION
	  );

	echo '<div class="notice notice-warning is-dismissible"><p>' . wp_kses_post( $message ) . '</p></div>';

	}

  /**
   * Register Widgets Category
   *
   */
	public function themezinho_add_widget_category( $elements_manager ) {
	  $elements_manager->add_category( 'themezinho', [ 'title' => esc_html__( 'Themezinho', 'themezinho' ) ] );


	}


	public function init_widgets() {

	  /*
	   * Register widgets and include widget files
	   */



		if ( !get_option( 'disable_skolka_slider' ) == 1 ) {
		 require_once  __DIR__ . '/widgets/skolka-slider.php' ;
		 \Elementor\Plugin::instance()->widgets_manager->register( new Elementor\Skolka_Slider_Widget() );
		}

		if ( !get_option( 'disable_skolka_product_hero' ) == 1 ) {
		require_once  __DIR__ . '/widgets/skolka-product-hero.php' ;
		\Elementor\Plugin::instance()->widgets_manager->register( new Elementor\Skolka_Product_Hero_Widget() );
		}

		if ( !get_option( 'disable_skolka_headlines' ) == 1 ) {
		   require_once  __DIR__ . '/widgets/skolka-headlines.php' ;
		   \Elementor\Plugin::instance()->widgets_manager->register( new Elementor\Skolka_Headlines_Widget() );
		}

		if ( !get_option( 'disable_skolka_image' ) == 1 ) {
		   require_once  __DIR__ . '/widgets/skolka-image.php' ;
		   \Elementor\Plugin::instance()->widgets_manager->register( new Elementor\Skolka_Image_Widget() );
		}

		if ( !get_option( 'disable_skolka_text_editor' ) == 1 ) {
		   require_once  __DIR__ . '/widgets/skolka-text-editor.php' ;
		   \Elementor\Plugin::instance()->widgets_manager->register( new Elementor\Skolka_Text_Editor_Widget() );
		}

    if ( !get_option( 'disable_skolka_image_carousel' ) == 1 ) {
		   require_once  __DIR__ . '/widgets/skolka-image-carousel.php' ;
		   \Elementor\Plugin::instance()->widgets_manager->register( new Elementor\Skolka_Image_Carousel_Widget() );
		}

		if ( !get_option( 'disable_skolka_grouped_product_carousel' ) == 1 ) {
		   require_once  __DIR__ . '/widgets/skolka-grouped-product-carousel.php' ;
		   \Elementor\Plugin::instance()->widgets_manager->register( new Elementor\Skolka_Grouped_Product_Carousel_Widget() );
		}

    if ( !get_option( 'disable_skolka_grouped_product_grid' ) == 1 ) {
		   require_once  __DIR__ . '/widgets/skolka-grouped-product-grid.php' ;
		   \Elementor\Plugin::instance()->widgets_manager->register( new Elementor\Skolka_Grouped_Product_Grid_Widget() );
		}

		if ( !get_option( 'disable_skolka_product_list_grid' ) == 1 ) {
		   require_once  __DIR__ . '/widgets/skolka-product-list-grid.php' ;
		   \Elementor\Plugin::instance()->widgets_manager->register( new Elementor\Skolka_Product_List_Grid_Widget() );
		}

		if ( !get_option( 'disable_skolka_product_list_carousel' ) == 1 ) {
		   require_once  __DIR__ . '/widgets/skolka-product-list-carousel.php' ;
		   \Elementor\Plugin::instance()->widgets_manager->register( new Elementor\Skolka_Product_List_Carousel_Widget() );
		}


    if ( !get_option( 'disable_skolka_product_list_new' ) == 1 ) {
		   require_once  __DIR__ . '/widgets/skolka-new-product-list.php' ;
		   \Elementor\Plugin::instance()->widgets_manager->register( new Elementor\Skolka_Product_List_New_Widget() );
		}

		if ( !get_option( 'disable_skolka_outlet_product_list' ) == 1 ) {
		   require_once  __DIR__ . '/widgets/skolka-outlet-product-list.php' ;
		   \Elementor\Plugin::instance()->widgets_manager->register( new Elementor\Skolka_Outlet_Product_List_Widget() );
		}

		if ( !get_option( 'disable_skolka_category_grid' ) == 1 ) {
		   require_once  __DIR__ . '/widgets/skolka-category-grid.php' ;
		   \Elementor\Plugin::instance()->widgets_manager->register( new Elementor\Skolka_Category_Grid_Widget() );
		}

		if ( !get_option( 'disable_skolka_image_banner' ) == 1 ) {
		   require_once  __DIR__ . '/widgets/skolka-image-banner.php' ;
		   \Elementor\Plugin::instance()->widgets_manager->register( new Elementor\Skolka_Image_Banner_Widget() );
		}

		if ( !get_option( 'disable_skolka_category_banner' ) == 1 ) {
		   require_once  __DIR__ . '/widgets/skolka-category-banner.php' ;
		   \Elementor\Plugin::instance()->widgets_manager->register( new Elementor\Skolka_Category_Banner_Widget() );
		}

		if ( !get_option( 'disable_skolka_brand' ) == 1 ) {
		   require_once  __DIR__ . '/widgets/skolka-brand.php' ;
		   \Elementor\Plugin::instance()->widgets_manager->register( new Elementor\Skolka_Brand_Widget() );
		}

		if ( !get_option( 'disable_skolka_brands_carousel' ) == 1 ) {
		   require_once  __DIR__ . '/widgets/skolka-brands-carousel.php' ;
		   \Elementor\Plugin::instance()->widgets_manager->register( new Elementor\Skolka_Brands_Carousel_Widget() );
		}

		if ( !get_option( 'disable_skolka_brands_list' ) == 1 ) {
		   require_once  __DIR__ . '/widgets/skolka-brands-list.php' ;
		   \Elementor\Plugin::instance()->widgets_manager->register( new Elementor\Skolka_Brands_List_Widget() );
		}

    if ( !get_option( 'disable_skolka_brands_grid' ) == 1 ) {
		   require_once  __DIR__ . '/widgets/skolka-brands-grid.php' ;
		   \Elementor\Plugin::instance()->widgets_manager->register( new Elementor\Skolka_Brands_Grid_Widget() );
		}

		if ( !get_option( 'disable_skolka_reviews_carousel' ) == 1 ) {
		   require_once  __DIR__ . '/widgets/skolka-reviews-carousel.php' ;
		   \Elementor\Plugin::instance()->widgets_manager->register( new Elementor\Skolka_Reviews_Carousel_Widget() );
		}

		if ( !get_option( 'disable_skolka_button' ) == 1 ) {
		   require_once  __DIR__ . '/widgets/skolka-button.php' ;
		   \Elementor\Plugin::instance()->widgets_manager->register( new Elementor\Skolka_Button_Widget() );
		}

		if ( !get_option( 'disable_skolka_recent_posts' ) == 1 ) {
		   require_once  __DIR__ . '/widgets/skolka-recent-posts.php' ;
		   \Elementor\Plugin::instance()->widgets_manager->register( new Elementor\Skolka_Recent_Posts_Widget() );
		}

		if ( !get_option( 'disable_skolka_side_menu' ) == 1 ) {
		   require_once  __DIR__ . '/widgets/skolka-side-menu.php' ;
		   \Elementor\Plugin::instance()->widgets_manager->register( new Elementor\Skolka_Side_Menu_Widget() );
		}

		if ( !get_option( 'disable_skola_Newsletter' ) == 1 ) {
		   require_once  __DIR__ . '/widgets/skolka-newsletter.php' ;
		   \Elementor\Plugin::instance()->widgets_manager->register( new Elementor\Skolka_Newsletter_Widget() );
		}

		if ( !get_option( 'disable_skolka_accordion' ) == 1 ) {
		   require_once  __DIR__ . '/widgets/skolka-accordion.php' ;
		   \Elementor\Plugin::instance()->widgets_manager->register( new Elementor\Skolka_Accordion_Widget() );
		}

		if ( !get_option( 'disable_skolka_tabs' ) == 1 ) {
		   require_once  __DIR__ . '/widgets/skolka-tabs.php' ;
		   \Elementor\Plugin::instance()->widgets_manager->register( new Elementor\Skolka_Tabs_Widget() );
		}





	}


}
Themezinho_Elementor_Addons::instance();
