<?php

namespace Elementor;

if ( !defined( 'ABSPATH' ) ) {
exit;
}

class Skolka_Product_Hero_Widget extends Widget_Base {
	public function get_name() {
	  return 'skolka-product-hero';
	}
	public function get_title() {
	  return 'Product Hero';
	}
	public function get_icon() {
	  return 'eicon-post-slider';
	}
	public function get_categories() {
	  return [ 'themezinho' ];
	}

  // Registering Controls
	protected function register_controls() {

	  /*****   START CONTROLS SECTION   ******/
	  $this->start_controls_section( 'skolka_product_hero', [
		'label' => esc_html__( 'Product Hero', 'themezinho' ),
	  ] );

	  $this->add_control(
		'hero_bg_color',
		array(
		'label' => __( 'Hero BG Color', 'themezinho' ),
		'type' => Controls_Manager::COLOR,
		'selectors' => [
				'{{WRAPPER}} .hero-bg' => 'background-color: {{VALUE}};'
			],
	  )
	  );



	  $this->add_control(
		'hero_content_color',
		array(
		'label' => __( 'Hero Content Color', 'themezinho' ),
		'type' => Controls_Manager::COLOR,
		'selectors' => [
				'{{WRAPPER}} .product-hero' => 'color: {{VALUE}};'
			],
	  )
	  );

		$this->add_control(
	 'hr0',
	 [
		 'type' => \Elementor\Controls_Manager::DIVIDER,
	 ]
	 );

	  $this->add_control(
		'hero_tagline',
		array(
		'label' => __( 'Tagline', 'themezinho' ),
		'type' => Controls_Manager::TEXT,
	  )
	  );

	  $this->add_control(
		'hero_title',
		array(
		'label' => __( 'Title', 'themezinho' ),
		'type' => Controls_Manager::TEXTAREA,
	  )
	  );

	  $this->add_control(
		'hero_link_label',
		array(
		'label' => __( 'Link Label', 'themezinho' ),
		'type' => Controls_Manager::TEXT,
		'default' => __( 'Link', 'themezinho' ),
	  )
	  );

	  $this->add_control(
		'hero_link_url',
		array(
		'label' => __( 'Link URL', 'themezinho' ),
		'type' => Controls_Manager::TEXT,
		'default' => __( '#', 'themezinho' ),
	  )
	  );


		$this->add_control(
	 'hr1',
	 [
		 'type' => \Elementor\Controls_Manager::DIVIDER,
	 ]
	 );

	  $this->add_control(
		'display_bottom_bar',
		array(
		'label' => __( 'Display Bottom Bar', 'themezinho' ),
		'type' => Controls_Manager::SWITCHER,
		'no' => esc_html__( 'No', 'themezinho' ),
		'yes' => esc_html__( 'Yes', 'themezinho' ),
		'return_value' => 'yes',
		'default' => 'no',
	  )
	  );

	  $this->add_control(
		'bottom_bar_button_label',
		array(
		'label' => __( 'Button Label', 'themezinho' ),
		'type' => Controls_Manager::TEXT,
		'default' => __( 'Button', 'themezinho' ),
		'condition' => ['display_bottom_bar' => 'yes']
	  )
	  );

	  $this->add_control(
		'bottom_bar_button_url',
		array(
		'label' => __( 'Button URL', 'themezinho' ),
		'type' => Controls_Manager::TEXT,
		'default' => __( '#', 'themezinho' ),
		'condition' => ['display_bottom_bar' => 'yes']
	  )
	  );


	  $this->add_control(
		'bottom_bar_text',
		array(
		'label' => __( 'Text', 'themezinho' ),
		'type' => Controls_Manager::TEXT,
		'condition' => ['display_bottom_bar' => 'yes']
	  )
	  );


	   $this->add_control( 'hero_items', [
		'type' => Controls_Manager::REPEATER,
		'seperator' => 'before',
		'deafult' => '',
		'fields' => [

		[
		  'name' => 'hero_image',
		  'label' => esc_html__( 'Image', 'themezinho' ),
		  'type' => Controls_Manager::MEDIA,
			'default' => __( '', 'themezinho' ),
		],

		]
	  ] );


	  $this->end_controls_section();
	  /*****   END CONTROLS SECTION   ******/

	}
	protected function render() {
	  $settings = $this->get_settings_for_display();

		?>

	<header class="product-hero">
	  <div class="hero-bg"></div>
	  <div class="hero-contents">
	  <small><?php echo wp_kses_post( $settings['hero_tagline'], array() ); ?></small>
	  <h2><?php echo wp_kses_post( $settings['hero_title'], array() ); ?></h2>
	  <a href="<?php echo wp_kses_post( $settings['hero_link_url'], array() ); ?>" class="hero-link"
						  <?php
							if ( $settings['hero_content_color'] ) {
								?>
			 style="color:<?php echo esc_attr($settings['hero_content_color']); ?>; border-color:<?php echo esc_attr($settings['hero_content_color']); ?>;"<?php } ?>><?php echo esc_html( $settings['hero_link_label'] ); ?></a>
	  </div>
	  <div class="hero-carousel-wrapper">
	  <div class="hero-carousel">
		<div class="swiper-wrapper">
			<?php foreach ( $settings[ 'hero_items' ] as $item ) { ?>
		  <div class="swiper-slide">
			<?php
			$image = wp_get_attachment_image_src( $item['hero_image']['id'], 'slide_image_size' );
			if ( $item['hero_image']['url'] ) { ?>
			<figure>
			  <img src="<?php echo esc_url( $image[0] ); ?>" alt="Image">
			</figure>
			  <?php } ?>
			</div>
			<?php } ?>
	  </div>
		</div>
		</div>
		<div class="bottom-bar"
		<?php
		if ( $settings['hero_content_color'] ) {
			?>
			 style="color:<?php echo esc_attr($settings['hero_content_color']); ?>;"<?php } ?>>
			 <div class="line"<?php
	 		if ( $settings['hero_content_color'] ) {
	 			?>
	 			 style="background-color:<?php echo esc_attr($settings['hero_content_color']); ?>;"<?php } ?>></div>
		  <a href="<?php echo esc_url( $settings['bottom_bar_button_url'] ); ?>"
							  <?php
								if ( $settings['hero_content_color'] ) {
									?>
				 style="color:<?php echo esc_attr($settings['hero_content_color']); ?>; border-color:<?php echo esc_attr($settings['hero_content_color']); ?>;"<?php } ?>>
				 + <?php echo esc_html( $settings['bottom_bar_button_label'] ); ?></a> <span><?php echo esc_html( $settings['bottom_bar_text'] ); ?></span>
		</div>
	</header>

<?php


	}
}
