<?php

namespace Elementor;

if ( !defined( 'ABSPATH' ) )exit;

class Skolka_Reviews_Carousel_Widget extends Widget_Base {
  public function get_name() {
    return 'skolka-brand-carousel';
  }
  public function get_title() {
    return 'Reviews Carousel';
  }
  public function get_icon() {
    return 'eicon-gallery-justified';
  }
  public function get_categories() {
    return [ 'themezinho' ];
  }

  // Registering Controls
  protected function register_controls() {

    /*****   START CONTROLS SECTION   ******/
    $this->start_controls_section( 'skolka_reviews_carousel_section', [
      'label' => esc_html__( 'Reviews Carousel', 'themezinho' ),
    ] );


    $this->add_control(
      'total_reviews',
      array(
        'label' => esc_html__( 'Total Reviews', 'themezinho' ),
        'type' => \Elementor\ Controls_Manager::TEXT,
        'default' => '24',

      )
    );


    $this->add_control(
      'carousel_loop',
      array(
        'label' => esc_html__( 'Carousel Loop', 'themezinho' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'false' => esc_html__( 'No', 'themezinho' ),
				'true' => esc_html__( 'Yes', 'themezinho' ),
				'return_value' => 'yes',
				'default' => 'false',

      )
    );
    $this->add_control(
      'drag_drop',
      array(
        'label' => esc_html__( 'Carousel Drag/Drop', 'themezinho' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
        'no' => esc_html__( 'No', 'themezinho' ),
				'yes' => esc_html__( 'Yes', 'themezinho' ),
				'return_value' => 'yes',
				'default' => 'no'
      )
    );

    $this->add_control(
      'display_controls',
      array(
        'label' => esc_html__( 'Display Controls', 'themezinho' ),
				'type' => \Elementor\Controls_Manager::SELECT,
        'options' => [
          'yes' => esc_html__( 'Yes', 'themezinho' ),
          'no' => esc_html__( 'No', 'themezinho' )
        ],
        'default' => 'yes'

      )
    );

    $this->add_control(
      'arrows',
      array(
        'label' => esc_html__( 'Display Arrows', 'themezinho' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'yes' => esc_html__( 'Yes', 'themezinho' ),
				'no' => esc_html__( 'No', 'themezinho' ),
				'return_value' => 'yes',
				'default' => 'yes',
        'condition' => ['display_controls' => 'yes']

      )
    );

    $this->add_control(
      'pagination',
      array(
        'label' => esc_html__( 'Display Pagination', 'themezinho' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'yes' => esc_html__( 'Yes', 'themezinho' ),
				'no' => esc_html__( 'No', 'themezinho' ),
				'return_value' => 'yes',
				'default' => 'yes',
        'condition' => ['display_controls' => 'yes']
      )
    );



    $this->add_control(
      'columns',
      array(
        'label' => __( 'Grid Columns', 'themezinho' ),
        'type' => Controls_Manager::SELECT,
        'options' => [
          '2' => esc_html__( '2', 'themezinho' ),
          '3' => esc_html__( '3', 'themezinho' ),
          '4' => esc_html__( '4', 'themezinho' ),
          '5' => esc_html__( '5', 'themezinho' ),
          '6' => esc_html__( '6', 'themezinho' ),
          '7' => esc_html__( '7', 'themezinho' ),
          '8' => esc_html__( '8', 'themezinho' )
        ],
        'default' => '1'
      )
    );


    $this->end_controls_section();
    /*****   END CONTROLS SECTION   ******/

  }
  protected function render() {
    $settings = $this->get_settings_for_display();


    ?>
<?php
global $wpdb;
$results = $wpdb->get_results( "SELECT * FROM $wpdb->comments c
      JOIN $wpdb->commentmeta cm ON c.comment_ID = cm.comment_id
      WHERE c.comment_type='review'
      AND cm.meta_key = 'rating'
      ORDER BY c.comment_date DESC LIMIT 5" );
if ( $results ) {
  ?>
  <div class="swiper-carousel recent-reviews" data-column="<?php echo $settings['columns']; ?>" data-loop="<?php echo $settings['carousel_loop']; ?>" data-drag="<?php if ( $settings[ 'drag_drop' ] === 'yes' ) { ?>true<?php } else { ?> false <?php }?>">
  <div class="swiper">
    <div class="swiper-wrapper">
      <?php
      foreach ( $results as $review ) {
        $product = wc_get_product( $review->comment_post_ID );
        $reviewer_name = get_comment_author( $review->comment_ID );
        $reviewer_avatar = get_avatar( $review->comment_author_email, 50 );
        $rating = get_comment_meta( $review->comment_ID, 'rating', true );
        ?>
      <div class="swiper-slide">
        <div class="review-box">
        <div class="star-rating" title="Rated <?php echo esc_attr($rating); ?> out of 5"> <span style="width:<?php echo ( $rating * 100 / 5 ); ?>%;"><strong class="rating"><?php echo esc_html($rating); ?></strong> out of 5</span> </div>
        <p> <?php echo esc_html($review->comment_content); ?> </p>
        <a href="<?php echo get_permalink( $review->comment_post_ID ); ?>"><?php echo esc_html($product->get_name()); ?></a>
        <figure> <?php echo $reviewer_avatar ?> </figure>
        <h6><?php echo esc_html($reviewer_name); ?></h6>
      </div>
    </div>
      <?php  } ?>
    </div>


  </div>

  <?php if ( $settings[ 'display_controls' ] === 'yes' ) { ?>
    <?php if ( $settings[ 'arrows' ] === 'yes' ) { ?>
      <div class="slider-button-prev">
        <svg width="24" height="24" viewBox="0 0 24 24" fill="#ffffff">
          <path d="M14.7105 17.2998C14.3205 17.6898 13.6905 17.6898 13.3005 17.2998L8.71047 12.7098C8.32047 12.3198 8.32047 11.6898 8.71047 11.2998L13.3005 6.70979C13.6905 6.31979 14.3205 6.31979 14.7105 6.70979C15.1005 7.09979 15.1005 7.72978 14.7105 8.11979L10.8305 12.0098L14.7105 15.8898C15.1005 16.2798 15.0905 16.9198 14.7105 17.2998Z"></path>
        </svg>
      </div>
        <?php } ?>
        <?php if ( $settings[ 'arrows' ] === 'yes' ) { ?>
      <div class="slider-button-next">
        <svg width="24" height="24" viewBox="0 0 24 24" fill="#ffffff" >
          <path d="M8.70995 6.70998C9.09995 6.31998 9.72995 6.31998 10.1199 6.70998L14.7099 11.3C15.0999 11.69 15.0999 12.32 14.7099 12.71L10.1199 17.3C9.72995 17.69 9.09995 17.69 8.70995 17.3C8.31995 16.91 8.31995 16.28 8.70995 15.89L12.5899 12L8.70995 8.11998C8.31995 7.72998 8.32995 7.08998 8.70995 6.70998Z"></path>
        </svg></div>
        <?php } ?>
  <?php } ?>
  
  <?php if ( $settings[ 'pagination' ] === 'yes' ) { ?>
<div class="swiper-pagination"></div>
  <?php } ?>
</div>
<?php  } else { ?>
No reviews found.
<?php
}
?>
<?php


}
}
