<?php

namespace Elementor;

if ( !defined( 'ABSPATH' ) ) {
exit;
}

class Skolka_Slider_Widget extends Widget_Base {
	public function get_name() {
	  return 'skolka-slider';
	}
	public function get_title() {
	  return 'Slider';
	}
	public function get_icon() {
	  return 'eicon-post-slider';
	}
	public function get_categories() {
	  return [ 'themezinho' ];
	}

  // Registering Controls
	protected function register_controls() {

	  /*****   START CONTROLS SECTION   ******/
	  $this->start_controls_section( 'skolka_slider', [
		'label' => esc_html__( 'Slider', 'themezinho' ),
	  ] );

	  $this->add_control(
		'slider_bg_color',
		array(
		'label' => __( 'Slider BG Color', 'themezinho' ),
		'type' => Controls_Manager::COLOR,
	  )
	  );

	  $this->add_control(
		'slider_content_color',
		array(
		'label' => __( 'Slider Content Color', 'themezinho' ),
		'type' => Controls_Manager::COLOR,
	  )
	  );

		 $this->add_control( 'slider_items', [
		'type' => Controls_Manager::REPEATER,
		'seperator' => 'before',
		'fields' => [

		[
		  'name' => 'slider_image',
		  'label' => esc_html__( 'Image', 'themezinho' ),
		  'type' => Controls_Manager::MEDIA,
			'default' => ''
		],

		[
		  'name' => 'slider_tagline',
		  'label' => esc_html__( 'Tagline', 'themezinho' ),
		  'type' => Controls_Manager::TEXT,
		  'default' => 'Tagline'
		],

		[
		  'name' => 'slider_headline',
		  'label' => esc_html__( 'Headline', 'themezinho' ),
		  'type' => Controls_Manager::TEXT,
		  'default' => 'Headline'
		],

		[
		  'name' => 'slider_content',
		  'label' => esc_html__( 'Content', 'themezinho' ),
		  'type' => Controls_Manager::WYSIWYG,
		  'default' => ''
		],


		[
		  'name' => 'display_button',
		  'label' => esc_html__( 'Button', 'themezinho' ),
		  'type' => Controls_Manager::SWITCHER,
		  'no' => esc_html__( 'No', 'themezinho' ),
		  'yes' => esc_html__( 'Yes', 'themezinho' ),
		  'return_value' => 'yes',
		  'default' => 'no',
		],

		[
		  'name' => 'slider_button_label',
		  'label' => esc_html__( 'Label', 'themezinho' ),
		  'type' => Controls_Manager::TEXT,
		  'default' => esc_html__( 'Button Label', 'themezinho' ),
		  'condition' => ['display_button' => 'yes']
		],

		[
		  'name' => 'slider_button_link',
		  'label' => esc_html__( 'Link', 'themezinho' ),
		  'type' => Controls_Manager::URL,
		  'placeholder' => esc_html__( 'https://your-link.com', 'themezinho' ),
		  'dynamic' => [
			'active' => false,
		  ],
		  'condition' => ['display_button' => 'yes']
		],




		]
	  ] );


	  $this->end_controls_section();
	  /*****   END CONTROLS SECTION   ******/

	}
	protected function render() {
	  $settings = $this->get_settings_for_display();

		?>

	<header class="skolka-slider" style="color:<?php echo wp_kses_post( $settings['slider_content_color'], array() ); ?>;">
	  <div class="skolka-slider-bg" style="background-color:<?php echo wp_kses_post( $settings['slider_bg_color'], array() ); ?>;"></div>
	  <div class="slider-contents">
		<div class="swiper-wrapper">
		  <?php foreach ( $settings[ 'slider_items' ] as $item ) { ?>
		  <div class="swiper-slide">
			<?php
				if ( $item[ 'slider_tagline' ] ) {
					?>
					<small><?php echo wp_kses_post($item['slider_tagline']); ?></small><?php } ?>
			<?php
				if ( $item[ 'slider_headline' ] ) {
					?>
					<h2><?php echo wp_kses_post($item['slider_headline']); ?></h2><?php } ?>
			<?php
				if ( $item[ 'slider_content' ] ) {
					?>
					<div class="content"><?php echo wp_kses_post($item['slider_content']); ?></div><?php } ?>
			<?php
				if ('yes' == $item['display_button']) {
					?>
					<a href="<?php echo wp_kses_post($item['slider_button_link']['url']); ?>" class="slider-button"><?php echo wp_kses_post($item['slider_button_label']); ?></a><?php } ?>
		  </div>
		  <?php } ?>
		</div>
	  </div>
	  <div class="slider-images-wrapper">
	  <div class="slider-images">
		<div class="swiper-wrapper">
			<?php foreach ( $settings[ 'slider_items' ] as $item ) { ?>
		  <div class="swiper-slide">
			<?php
			$image = wp_get_attachment_image_src( $item['slider_image']['id'], 'slide_image_size' );
			if ( $item['slider_image']['url'] ) { ?>
			<figure>
			  <img src="<?php echo esc_url( $image[0] ); ?>" alt="Image">
			</figure>
			  <?php } ?>
			</div>
			<?php } ?>
	  </div>
	  <div class="slider-button-prev" style="background-color:<?php echo wp_kses_post( $settings['slider_bg_color'], array() ); ?>;">
		<svg width="24" height="24" viewBox="0 0 24 24" fill="<?php echo wp_kses_post( $settings['slider_content_color'], array() ); ?>">
		  <path d="M14.7105 17.2998C14.3205 17.6898 13.6905 17.6898 13.3005 17.2998L8.71047 12.7098C8.32047 12.3198 8.32047 11.6898 8.71047 11.2998L13.3005 6.70979C13.6905 6.31979 14.3205 6.31979 14.7105 6.70979C15.1005 7.09979 15.1005 7.72978 14.7105 8.11979L10.8305 12.0098L14.7105 15.8898C15.1005 16.2798 15.0905 16.9198 14.7105 17.2998Z"></path>
		</svg>
	  </div>
	  <div class="slider-button-next" style="background-color:<?php echo wp_kses_post( $settings['slider_bg_color'], array() ); ?>;">
		<svg width="24" height="24" viewBox="0 0 24 24" fill="<?php echo wp_kses_post( $settings['slider_content_color'], array() ); ?>">
		<path d="M8.70995 6.70998C9.09995 6.31998 9.72995 6.31998 10.1199 6.70998L14.7099 11.3C15.0999 11.69 15.0999 12.32 14.7099 12.71L10.1199 17.3C9.72995 17.69 9.09995 17.69 8.70995 17.3C8.31995 16.91 8.31995 16.28 8.70995 15.89L12.5899 12L8.70995 8.11998C8.31995 7.72998 8.32995 7.08998 8.70995 6.70998Z"></path>
	  </svg>
	  </div>
		</div>
		</div>
	</header>

<?php


	}
}
